import { AnyT, IActionsFactoryWrapper, IActionsRenderedWrapper, IAlwaysDirtyWrapper, IAlwaysResettableWrapper, IChangeableWrapper, ICompactWrapper, IDisabledWrapper, IEntity, IFormConfigurationWrapper, IFormIdWrapper, IFormWrapper, IFullWrapper, IOnBeforeSubmitWrapper, IOnChangeWrapper, IOnClickWrapper, IOnEmptyDictionaryWrapper, IOnLoadDictionaryWrapper, IOnResetWrapper, IOnSubmitWrapper, IOnValidWrapper, IReadOnlyWrapper, IResetActionRenderedWrapper, IResetConfigurationWrapper, IResetIconWrapper, IResetTextWrapper, ISubmitConfigurationWrapper, ISubmitIconWrapper, ISubmitTextWrapper, IValidateOnMountWrapper, IValidWrapper } from '../definitions.interface';
import { IGenericEditableEntity, IExtendedEntity } from './entity-definition.interface';
import { IApiEntity } from './api-definition.interface';
import { IFieldChangeEntity } from './field-definition.interface';
import { IButtonConfigurationEntity, IButtonProps, IGenericButtonEntity } from './button-definition.interface';
import { IContainerProps } from './props-definition.interface';
import { IGenericComponentProps } from './generic-component-definition.interface';
/**
 * @generic-entity
 * @stable [16.01.2020]
 */
interface IGenericFormEntity extends IActionsFactoryWrapper<(defaultActions: IFormExtraButtonEntity[]) => IFormExtraButtonEntity[]>, IActionsRenderedWrapper, IAlwaysDirtyWrapper, IAlwaysResettableWrapper, IButtonConfigurationEntity, IChangeableWrapper, ICompactWrapper, IDisabledWrapper, IFormIdWrapper, IFullWrapper, IReadOnlyWrapper, IResetActionRenderedWrapper, IResetConfigurationWrapper<IButtonProps>, IResetIconWrapper, IResetTextWrapper, ISubmitConfigurationWrapper<IButtonProps>, ISubmitIconWrapper, ISubmitTextWrapper, IValidateOnMountWrapper, IValidWrapper {
}
/**
 * @entity
 * @stable [05.04.2020]
 */
export interface IFormEditableEntity<TEntity = IEntity> extends IFormWrapper<IGenericEditableEntity<TEntity>> {
}
/**
 * @entity
 * @stable [26.03.2020]
 */
export interface IExtendedFormEditableEntity<TEntity = IEntity> extends IFormEditableEntity<TEntity>, IExtendedEntity<TEntity> {
}
/**
 * @stable [25.09.2019]
 */
export interface IBehavioralFormEntity<TEntity extends IEntity = IEntity> extends IExtendedFormEditableEntity<TEntity>, IOnBeforeSubmitWrapper<IApiEntity<TEntity>, boolean>, IOnChangeWrapper<IFieldChangeEntity>, IOnEmptyDictionaryWrapper<(dictionary?: string, payload?: IApiEntity) => void>, IOnLoadDictionaryWrapper<(items: AnyT, dictionary?: string) => void>, IOnResetWrapper, IOnSubmitWrapper<IApiEntity<TEntity>>, IOnValidWrapper {
}
/**
 * @stable [27.09.2019]
 */
export interface IFormExtraButtonEntity extends IGenericButtonEntity, IOnClickWrapper<IApiEntity> {
}
/**
 * @props
 * @stable [27.09.2019]
 */
export interface IFormProps<TEntity = IEntity> extends IGenericComponentProps, IGenericFormEntity, IBehavioralFormEntity<TEntity> {
}
/**
 * @configuration-entity
 * @stable [04.01.2020]
 */
export interface IFormConfigurationEntity<TProps extends IFormProps = IFormProps> extends IFormConfigurationWrapper<TProps> {
}
/**
 * TODO
 * @deprecated Use IExtendedFormEditableEntity
 */
export interface IFormContainerProps<TEntity = IEntity, TDictionaries = {}, TPermissions = {}> extends IContainerProps<TDictionaries, TPermissions>, IBehavioralFormEntity<TEntity>, IFormConfigurationEntity {
}
/**
 * @entity
 * @stable [03.02.2020]
 */
export interface IFormValidEntity extends IValidWrapper {
}
/**
 * @default-entity
 * @stable [21.02.2020]
 */
export declare const DEFAULT_FORM_FIELD_CONTROLLER_ENTITY: Readonly<IGenericFormEntity>;
/**
 * @default-entity
 * @stable [21.02.2020]
 */
export declare const DEFAULT_FULL_FORM_FIELD_CONTROLLER_ENTITY: Readonly<IGenericFormEntity>;
/**
 * @initial-entity
 * @stable [27.09.2019]
 */
export declare const INITIAL_FORM_ENTITY: Readonly<IGenericEditableEntity<import("core/definitions.interface").IKeyValue>>;
/**
 * @classes
 * @stable [23.03.2020]
 */
export declare enum FormClassesEnum {
    FORM = "rac-form",
    FORM_ACTIONS = "rac-form__actions",
    FORM_BODY = "rac-form__body",
    FULL_FORM = "rac-full-form"
}
/**
 * @stable [01.04.2020]
 */
export declare const FORM_ACTIVE_VALUE_ACTION_TYPE = "form.active.value";
export declare const FORM_CHANGE_ACTION_TYPE = "form.change";
export declare const FORM_CLEAR_ACTION_TYPE = "form.clear";
export declare const FORM_DEFAULT_CHANGE_ACTION_TYPE = "form.default.change";
export declare const FORM_DESTROY_ACTION_TYPE = "form.destroy";
export declare const FORM_INACTIVE_VALUE_ACTION_TYPE = "form.inactive.value";
export declare const FORM_PROGRESS_ACTION_TYPE = "form.progress";
export declare const FORM_RESET_ACTION_TYPE = "form.reset";
export declare const FORM_SUBMIT_ACTION_TYPE = "form.submit";
export declare const FORM_SUBMIT_DONE_ACTION_TYPE: string;
export declare const FORM_SUBMIT_ERROR_ACTION_TYPE: string;
export declare const FORM_SUBMIT_FINISH_ACTION_TYPE = "form.submit.finish";
export declare const FORM_VALID_ACTION_TYPE = "form.valid";
export {};
