import { IEffectsAction } from 'redux-effects-promise';
import { IApiEntity, IDictionariesEntity, IDictionariesWrapperEntity, IDictionaryEntity, IExtendedEntity, IExtendedFormEditableEntity, IFormEditableEntity, IGenericActiveQueryEntity, IGenericBaseSelectEntity, IGenericContainer, IGenericEditableEntity, IGenericListEntity, IGenericPagedEntity, IGenericPaginatedEntity, IGenericStoreEntity, IGenericTabPanelEntity, IListContainerProps, IListEntity, IListWrapperEntity, IOperationEntity, IOptionEntity, IQueryFilterEntity, ISelectOptionEntity, ISortDirectionEntity, ISortDirectionsEntity, ISortDirectionsWrapperEntity, IStackEntity, IStackItemEntity, IStackWrapperEntity, ITabPanelWrapperEntity, ITransportEntity, ITransportWrapperEntity, IUniversalApplicationEntity, IUnsavedFormChangesDialogContainerProps, IUserEntity, IUserWrapperEntity, ToolbarToolsEnum } from '../definition';
import { IActionsDisabledWrapper, IActiveValueWrapper, IDisabledWrapper, IEntity, IEntityIdTWrapper, IErrorWrapper, IFilterWrapper, IFormWrapper, IListWrapper, IOptionsWrapper, IProgressWrapper, IQueryWrapper, ISectionNameWrapper, IUserWrapper, IWaitingForOptionsWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string}
 */
export declare const selectTransportWrapperToken: (entity: ITransportWrapperEntity<ITransportEntity>) => string;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @returns {string[]}
 */
export declare const selectTransportWrapperQueue: (entity: ITransportWrapperEntity<ITransportEntity>) => string[];
/**
 * @stable [13.02.2020]
 * @param {TErrorWrapper} entity
 * @returns {TResult}
 */
export declare const selectError: <TResult = any, TErrorWrapper extends IErrorWrapper<TResult> = IErrorWrapper<TResult>>(entity: TErrorWrapper) => TResult;
/**
 * @stable [29.02.2020]
 * @param {IExtendedFormEditableEntity<TEntity extends IEntity>} wrapper
 * @returns {IGenericEditableEntity<TEntity extends IEntity>}
 */
export declare const selectEditableEntity: <TEntity extends IEntity = IEntity>(wrapper: IExtendedFormEditableEntity<TEntity>) => IGenericEditableEntity<TEntity>;
/**
 * TODO
 * @deprecated
 */
export declare const selectListEntity: <TEntity extends IEntity = IEntity>(entity: IListWrapperEntity<TEntity>) => IListEntity<TEntity, any>;
/**
 * @stable [19.10.2019]
 * @param {IQueryWrapper} entity
 * @returns {string}
 */
export declare const selectQuery: (entity: IQueryWrapper<string>) => string;
/**
 * @stable [13.02.2020]
 * @param {IEffectsAction} action
 * @returns {TResult}
 */
export declare const selectErrorFromAction: <TResult = any>(action: IEffectsAction) => TResult;
/**
 * @stable [10.02.2020]
 * @param {ITabPanelWrapperEntity} entity
 * @returns {IGenericTabPanelEntity}
 */
export declare const selectTabPanelEntity: (entity: ITabPanelWrapperEntity) => IGenericTabPanelEntity;
/**
 * @stable [30.08.2019]
 * @param {IQueryFilterEntity} entity
 * @returns {string}
 */
export declare const selectFilterWrapperQuery: (entity: IQueryFilterEntity) => string;
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [28.01.2020]
 * @param {boolean} progress
 * @returns {IProgressWrapper}
 */
export declare const mapProgress: (progress: boolean) => IProgressWrapper<boolean>;
/**
 * @stable [29.01.2020]
 * @param {boolean} waitingForOptions
 * @returns {IWaitingForOptionsWrapper}
 */
export declare const mapWaitingForOptions: (waitingForOptions: boolean) => IWaitingForOptionsWrapper;
/**
 * @stable [28.01.2020]
 * @param {TValue} options
 * @returns {IOptionsWrapper<TValue>}
 */
export declare const mapOptions: <TValue>(options: TValue) => IOptionsWrapper<TValue>;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionsEntity} directions
 * @returns {ISortDirectionsWrapperEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: ISortDirectionsEntity) => ISortDirectionsWrapperEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [10.02.2020]
 * @param {IGenericTabPanelEntity} tabPanel
 * @returns {ITabPanelWrapperEntity}
 */
export declare const mapTabPanelEntity: (tabPanel: IGenericTabPanelEntity) => ITabPanelWrapperEntity;
/**
 * @stable [21.11.2019]
 * @param {ITabPanelWrapperEntity} tabPanelWrapperEntity
 * @returns {ITabPanelWrapperEntity}
 */
export declare const mapTabPanelWrapperEntity: (tabPanelWrapperEntity: ITabPanelWrapperEntity) => ITabPanelWrapperEntity;
/**
 * @stable [30.03.2020]
 * @param {TUser} user
 * @returns {IUserWrapper<TUser>}
 */
export declare const mapUser: <TUser = IUserEntity>(user: TUser) => IUserWrapper<TUser>;
/**
 * @stable [30.03.2020]
 * @param {string} sectionName
 * @returns {ISectionNameWrapper}
 */
export declare const mapSectionName: (sectionName: string) => ISectionNameWrapper;
/**
 * @stable [30.03.2020]
 * @param {TEntity} stack
 * @returns {IStackWrapperEntity<TEntity>}
 */
export declare const mapStack: <TEntity = IStackEntity>(stack: TEntity) => IStackWrapperEntity<TEntity>;
/**
 * @stable [28.03.2020]
 * @param {TTransport} transport
 * @returns {ITransportWrapperEntity<TTransport>}
 */
export declare const mapTransport: <TTransport = ITransportEntity>(transport: TTransport) => ITransportWrapperEntity<TTransport>;
/**
 * @stable [28.03.2020]
 * @param {TDictionaries} dictionaries
 * @returns {IDictionariesWrapperEntity<TDictionaries>}
 */
export declare const mapDictionaries: <TDictionaries = IDictionariesEntity>(dictionaries: TDictionaries) => IDictionariesWrapperEntity<TDictionaries>;
/**
 * @stable [12.10.2019]
 * @param {boolean} disabled
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabled: (disabled: boolean) => IDisabledWrapper<boolean>;
/**
 * @stable [10.09.2019]
 * @param {string} query
 * @returns {IQueryWrapper}
 */
export declare const mapQuery: (query: string) => IQueryWrapper<string>;
/**
 * @stable [29.02.2020]
 * @param {TEntity} filter
 * @returns {IFilterWrapper<TEntity>}
 */
export declare const mapFilter: <TEntity = string>(filter: TEntity) => IFilterWrapper<TEntity>;
/**
 * @stable [26.03.2020]
 * @param {TForm} form
 * @returns {IFormWrapper<TForm>}
 */
export declare const mapForm: <TForm>(form: TForm) => IFormWrapper<TForm>;
/**
 * @stable [11.04.2020]
 * @param {TValue} list
 * @returns {IListWrapper<TValue>}
 */
export declare const mapList: <TList>(list: TList) => IListWrapper<TList>;
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
export declare const mapActiveValue: <TActiveValue>(activeValue: TActiveValue) => IActiveValueWrapper<TActiveValue>;
/**
 * @stable [29.02.2020]
 * @param {IGenericActiveQueryEntity} filter
 * @returns {IQueryFilterEntity}
 */
export declare const mapQueryFilterEntity: (filter: IGenericActiveQueryEntity) => IQueryFilterEntity;
/**
 * TODO
 * @deprecated Use mapForm
 */
export declare const mapEditableEntity: <TEntity extends IEntity = IEntity>(form: IGenericEditableEntity<TEntity>) => IExtendedFormEditableEntity<TEntity>;
/**
 * @stable [10.09.2019]
 * @param {IGenericPagedEntity} entity
 * @returns {IGenericPagedEntity}
 */
export declare const mapPagedEntity: (entity: IGenericPagedEntity) => IGenericPagedEntity;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [04.10.2019]
 * @param {IListEntity} entity
 * @param {number} pageSize
 * @returns {IGenericPagedEntity}
 */
export declare const mapListPagedEntity: (entity: IListEntity<IEntity, any>, pageSize?: number) => IGenericPagedEntity;
/**
 * @stable [12.10.2019]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressWrapper: (entity: IProgressWrapper<boolean>) => IDisabledWrapper<boolean>;
/**
 * @stable [12.10.2019]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {IDisabledWrapper}
 */
export declare const mapDisabledProgressListWrapperEntity: (listWrapperEntity: IListWrapperEntity<IEntity>) => IDisabledWrapper<boolean>;
/**
 * @stable [04.10.2019]
 * @param {IListWrapperEntity} entity
 * @param {number} pageSize
 * @returns {IGenericPagedEntity}
 */
export declare const mapListWrapperPagedEntity: (entity: IListWrapperEntity<IEntity>, pageSize?: number) => IGenericPagedEntity;
/**
 * @stable [10.09.2019]
 * @param {IGenericPaginatedEntity} entity
 * @returns {IGenericPaginatedEntity}
 */
export declare const mapPaginatedEntity: (entity: IGenericPaginatedEntity) => IGenericPaginatedEntity;
/**
 * @stable [11.04.2020]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IListWrapperEntity}
 */
export declare const mapListWrapperEntity: (listWrapper: IListWrapperEntity<IEntity>) => IListWrapperEntity<IEntity>;
/**
 * @stable [30.03.2020]
 * @param {IUserWrapperEntity<TEntity>} wrapper
 * @returns {IUserWrapperEntity<TEntity>}
 */
export declare const mapUserWrapperEntity: <TEntity = IUserEntity>(wrapper: IUserWrapperEntity<TEntity>) => IUserWrapperEntity<TEntity>;
/**
 * @stable [30.03.2020]
 * @param {IStackWrapperEntity<TEntity>} wrapper
 * @returns {IStackWrapperEntity<TEntity>}
 */
export declare const mapStackWrapperEntity: <TEntity = IStackEntity>(wrapper: IStackWrapperEntity<TEntity>) => IStackWrapperEntity<TEntity>;
/**
 * @stable [28.03.2020]
 * @param {ITransportWrapperEntity<TTransport>} wrapper
 * @returns {ITransportWrapperEntity<TTransport>}
 */
export declare const mapTransportWrapperEntity: <TTransport = ITransportEntity>(wrapper: ITransportWrapperEntity<TTransport>) => ITransportWrapperEntity<TTransport>;
/**
 * @stable [28.03.2020]
 * @param {IDictionariesWrapperEntity<TDictionaries>} wrapper
 * @returns {IDictionariesWrapperEntity<TDictionaries>}
 */
export declare const mapDictionariesWrapperEntity: <TDictionaries = IDictionariesEntity>(wrapper: IDictionariesWrapperEntity<TDictionaries>) => IDictionariesWrapperEntity<TDictionaries>;
/**
 * @stable [30.03.2020]
 * @param {ISectionNameWrapper} wrapper
 * @returns {ISectionNameWrapper}
 */
export declare const mapSectionNameWrapper: (wrapper: ISectionNameWrapper) => ISectionNameWrapper;
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
export declare const mapActiveValueWrapper: <TValue>(wrapper: IActiveValueWrapper<TValue>) => IActiveValueWrapper<TValue>;
/**
 * @stable [21.12.2019]
 * @param {TEntity} entity
 * @param {IGenericEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedEntity: <TEntity extends IEntity = IEntity>(entity: TEntity, editableEntity: IGenericEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [25.12.2019]
 * @param {IGenericEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapNewExtendedEntity: <TEntity extends IEntity = IEntity>(editableEntity: IGenericEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [26.03.2020]
 * @param {TEntity} entity
 * @param {IGenericEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {IExtendedFormEditableEntity<TEntity extends IEntity>}
 */
export declare const mapExtendedFormEditableEntity: <TEntity extends IEntity = IEntity>(entity: TEntity, editableEntity: IGenericEditableEntity<TEntity>) => IExtendedFormEditableEntity<TEntity>;
/**
 * @stable [05.04.2020]
 * @param {IFormEditableEntity<TEntity>} wrapper
 * @returns {IFormEditableEntity<TEntity>}
 */
export declare const mapFormEditableEntity: <TEntity = IEntity>(wrapper: IFormEditableEntity<TEntity>) => IFormEditableEntity<TEntity>;
/**
 * @stable [26.03.2020]
 * @param {IGenericEditableEntity<TEntity>} editableEntity
 * @returns {IExtendedFormEditableEntity<TEntity extends IEntity>}
 */
export declare const mapNewExtendedEditableEntity: <TEntity = IEntity>(editableEntity: IGenericEditableEntity<TEntity>) => IExtendedFormEditableEntity<TEntity>;
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
export declare const mapApiEntity: <TEntity = IEntity>(extendedEntity: IExtendedEntity<TEntity>) => IApiEntity<TEntity>;
/**
 * @stable [06.09.2019]
 * @param {IListWrapperEntity} listWrapper
 * @param {IGenericEditableEntity} editableEntity
 * @returns {IExtendedEntity<TEntity extends IEntity>}
 */
export declare const mapListSelectedExtendedEntity: <TEntity extends IEntity>(listWrapper: IListWrapperEntity<TEntity>, editableEntity: IGenericEditableEntity<TEntity>) => IExtendedEntity<TEntity>;
/**
 * @stable [04.09.2019]
 * @param {IQueryFilterEntity} queryFilter
 * @returns {IQueryFilterEntity}
 */
export declare const mapQueryFilterWrapperEntity: (queryFilter: IQueryFilterEntity) => IQueryFilterEntity;
/**
 * @stable [10.09.2019]
 * @param {IQueryFilterEntity} entity
 * @returns {IQueryWrapper}
 */
export declare const mapFilterWrapperQuery: (entity: IQueryFilterEntity) => IQueryWrapper<string>;
/**
 * @stable [17.09.2019]
 * @param {boolean} actionsDisabled
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapActionsDisabled: (actionsDisabled: boolean) => IActionsDisabledWrapper;
/**
 * @stable [04.04.2020]
 * @param {IGenericListEntity} list
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapListActionsDisabled: (list: IGenericListEntity<IEntity, any>) => IActionsDisabledWrapper;
/**
 * @stable [04.04.2020]
 * @param {IListWrapperEntity} listWrapper
 * @returns {IActionsDisabledWrapper}
 */
export declare const mapListWrapperActionsDisabled: (listWrapper: IListWrapperEntity<IEntity>) => IActionsDisabledWrapper;
/**
 * @stable [11.10.2019]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<ISelectOptionEntity<TEntity extends IOptionEntity>>}
 */
export declare const mapSelectOptions: <TEntity extends IOptionEntity>(data: TEntity | TEntity[]) => ISelectOptionEntity<TEntity>[];
/**
 * @stable [18.09.2019]
 * @param {IExtendedFormEditableEntity} entity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectFormEntityToolbarToolsActiveFilter: (entity: IExtendedFormEditableEntity<IEntity>) => ToolbarToolsEnum[];
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => AnyT} accessor
 * @returns {Array<ISelectOptionEntity<TEntity>>}
 */
export declare const selectDictionaryEntityOptions: <TEntity>(dictionaryEntity: IDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => any) => ISelectOptionEntity<TEntity>[];
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TDictionaryEntity>} dictionaryEntity
 * @returns {boolean}
 */
export declare const selectDictionaryEntityLoading: <TDictionaryEntity>(dictionaryEntity: IDictionaryEntity<TDictionaryEntity>) => boolean;
/**
 * @stable [28.01.2020]
 * @param {IDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: TEntity[]) => TResult} accessor
 * @returns {IGenericBaseSelectEntity}
 */
export declare const mapDictionaryEntityField: <TEntity, TResult = TEntity[]>(dictionaryEntity: IDictionaryEntity<TEntity>, accessor?: (data: TEntity[]) => TResult) => IGenericBaseSelectEntity;
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasQueueOperations: (queue: string[], ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [25.11.2019]
 * @param {ITransportWrapperEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasTransportWrapperQueueOperations: (entity: ITransportWrapperEntity<ITransportEntity>, ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationInProgress: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const doesApplicationErrorExist: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationMessageVisible: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackEntity}
 */
export declare const selectStackEntity: (entity: IStackWrapperEntity<IStackEntity>) => IStackEntity;
/**
 * @stable [18.12.2019]
 * @param {IStackEntity} entity
 * @returns {IStackItemEntity[]}
 */
export declare const selectStackItemEntities: (entity: IStackEntity) => IStackItemEntity[];
/**
 * @stable [18.12.2019]
 * @param {IStackWrapperEntity} entity
 * @returns {IStackItemEntity[]}
 */
export declare const selectStackWrapperItemEntities: (entity: IStackWrapperEntity<IStackEntity>) => IStackItemEntity[];
/**
 * @stable [28.03.2020]
 * @param {IGenericStoreEntity<TDictionaries>} entity
 * @returns {IGenericStoreEntity<TDictionaries>}
 */
export declare const mapStoreEntity: <TDictionaries = {}>(entity: IGenericStoreEntity<TDictionaries>) => IGenericStoreEntity<TDictionaries>;
/**
 * @container-props-mapper
 * @stable [11.04.2020]
 * @param {IListContainerProps} props
 * @returns {IListContainerProps}
 */
export declare const mapListContainerProps: (props: IListContainerProps) => IListContainerProps;
/**
 * @container-props-mapper
 * @stable [11.04.2020]
 * @param {IFormEditableEntity<TEntity>} props
 * @param {IGenericContainer} proxyContainer
 * @returns {IUnsavedFormChangesDialogContainerProps}
 */
export declare const mapUnsavedFormChangesDialogContainerProps: <TEntity = IEntity>(props: IFormEditableEntity<TEntity>, proxyContainer: IGenericContainer<import("core/definition/generic-container-definition.interface").IGenericContainerProps<{}>, {}>) => IUnsavedFormChangesDialogContainerProps;
