import { IEffectsAction } from 'redux-effects-promise';
import { IActiveValueWrapper, IChangesWrapper, IDataWrapper, IDefaultChangesWrapper, IDictionariesWrapper, IDirectionsWrapper, IElementWrapper, IEntity, IEntityIdTWrapper, IEntityWrapper, IFilterWrapper, IFormWrapper, IListWrapper, IPayloadWrapper, IPreventEffectsWrapper, IQueueWrapper, IRawDataWrapper, ISectionNameWrapper, ISelectedWrapper, IStackWrapper, ITokenWrapper, ITransportWrapper, ITypeWrapper, IUserWrapper, IValidWrapper } from '../definitions.interface';
import { IFormEditableEntity, IGenericEditableEntity, IGenericListEntity, IListWrapperEntity, IPreviousActionWrapperEntity, ISortDirectionsEntity, ToolbarToolsEnum } from '../definition';
/**
 * @stable [30.03.2020]
 * @param {IQueueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectQueue: <TValue>(wrapper: IQueueWrapper<TValue>) => TValue;
/**
 * @stable [30.03.2020]
 * @param {IRawDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectRawData: <TValue = any>(wrapper: IRawDataWrapper<TValue>) => TValue;
/**
 * @stable [06.04.2020]
 * @param {IElementWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectElement: <TValue = any>(wrapper: IElementWrapper<TValue>) => TValue;
/**
 * @stable [12.04.2020]
 * @param {IDefaultChangesWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectDefaultChanges: <TValue = IEntity>(wrapper: IDefaultChangesWrapper<TValue>) => TValue;
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
export declare const selectEntityId: (entity: IEntityIdTWrapper) => string | number;
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectForm: <TValue>(wrapper: IFormWrapper<TValue>) => TValue;
/**
 * @stable [27.03.2020]
 * @param {IListWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectList: <TValue>(wrapper: IListWrapper<TValue>) => TValue;
/**
 * @stable [09.04.2020]
 * @param {IFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectFilter: <TValue = string>(wrapper: IFilterWrapper<TValue>) => TValue;
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectType: <TValue>(wrapper: ITypeWrapper<TValue>) => TValue;
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectToken: <TValue = string>(wrapper: ITokenWrapper<TValue>) => TValue;
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectChanges: <TResult = IEntity>(entity: IChangesWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
export declare const selectEntity: <TResult = IEntity>(entity: IEntityWrapper<TResult>) => TResult;
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
export declare const selectData: <TData>(wrapper: IDataWrapper<TData>) => TData;
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectActiveValue: <TValue>(wrapper: IActiveValueWrapper<TValue>) => TValue;
/**
 * @stable [30.03.2020]
 * @param {IPayloadWrapper<TPayload>} wrapper
 * @returns {TPayload}
 */
export declare const selectPayload: <TPayload>(wrapper: IPayloadWrapper<TPayload>) => TPayload;
/**
 * @stable [30.03.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
export declare const selectDataPayloadFromAction: <TPayload>(action: IEffectsAction) => TPayload;
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectValid: (wrapper: IValidWrapper) => boolean;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectValidFromAction: (wrapper: IEffectsAction) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffects: (wrapper: IPreventEffectsWrapper<boolean>) => boolean;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
export declare const selectPreventEffectsFromAction: (wrapper: IEffectsAction) => boolean;
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousAction: (wrapper: IPreviousActionWrapperEntity) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
export declare const selectPreviousActionFromAction: (wrapper: IEffectsAction) => IEffectsAction;
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
export declare const selectPreviousActionTypeFromAction: (action: IEffectsAction) => string;
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
export declare const selectSelected: <TEntity extends IEntity>(entity: ISelectedWrapper<TEntity>) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
export declare const selectSelectedEntityFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => TEntity;
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
export declare const selectSelectedEntityIdFromAction: <TEntity extends IEntity = IEntity>(action: IEffectsAction) => string | number;
/**
 * @stable [30.03.2020]
 * @param {IUserWrapper<TUser>} wrapper
 * @returns {TUser}
 */
export declare const selectUser: <TUser>(wrapper: IUserWrapper<TUser>) => TUser;
/**
 * @stable [30.03.2020]
 * @param {IStackWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
export declare const selectStack: <TEntity>(wrapper: IStackWrapper<TEntity>) => TEntity;
/**
 * @stable [30.03.2020]
 * @param {ITransportWrapper<TTransport>} wrapper
 * @returns {TTransport}
 */
export declare const selectTransport: <TTransport>(wrapper: ITransportWrapper<TTransport>) => TTransport;
/**
 * @stable [30.03.2020]
 * @param {IDictionariesWrapper<TDictionaries>} wrapper
 * @returns {TDictionaries}
 */
export declare const selectDictionaries: <TDictionaries>(wrapper: IDictionariesWrapper<TDictionaries>) => TDictionaries;
/**
 * @stable [30.03.2020]
 * @param {ISectionNameWrapper} wrapper
 * @returns {string}
 */
export declare const selectSectionName: (wrapper: ISectionNameWrapper) => string;
/**
 * @stable [30.03.2020]
 * @param {IListWrapperEntity<TEntity extends IEntity>} listWrapperEntity
 * @returns {TEntity}
 */
export declare const selectListSelectedEntity: <TEntity extends IEntity>(listWrapperEntity: IListWrapperEntity<TEntity>) => TEntity;
/**
 * @stable [04.04.2020]
 * @param {IDirectionsWrapper<TValue>} wrapper
 * @returns {TValue}
 */
export declare const selectDirections: <TValue>(wrapper: IDirectionsWrapper<TValue>) => TValue;
/**
 * @stable [04.04.2020]
 * @param {IGenericListEntity} entity
 * @returns {ISortDirectionsEntity}
 */
export declare const selectListEntityDirections: (entity: IGenericListEntity<IEntity, any>) => ISortDirectionsEntity;
/**
 * @stable [09.04.2020]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TData}
 */
export declare const selectListWrapperRawDataEntity: <TData = any>(listWrapperEntity: IListWrapperEntity<IEntity>) => TData;
/**
 * @stable [09.04.2020]
 * @param {IFormEditableEntity<TEntity>} entity
 * @returns {TEntity}
 */
export declare const selectFormEditableEntityChanges: <TEntity = IEntity>(entity: IFormEditableEntity<TEntity>) => TEntity;
/**
 * @stable [09.04.2020]
 * @param {IGenericEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
export declare const selectEditableEntityToolbarToolsActiveFilter: (editableEntity: IGenericEditableEntity<import("core/definitions.interface").IKeyValue>) => ToolbarToolsEnum[];
