"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var nvl_1 = require("./nvl");
var definition_1 = require("../definition");
var cond_1 = require("./cond");
/**
 * @stable [30.03.2020]
 * @param {IQueueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectQueue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.queue;
};
/**
 * @stable [30.03.2020]
 * @param {IRawDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectRawData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.rawData;
};
/**
 * @stable [06.04.2020]
 * @param {IElementWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectElement = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.element;
};
/**
 * @stable [12.04.2020]
 * @param {IDefaultChangesWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectDefaultChanges = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.defaultChanges;
};
/**
 * @stable [27.03.2020]
 * @param {IEntityIdTWrapper} entity
 * @returns {EntityIdT}
 */
exports.selectEntityId = function (entity) { return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.id; };
/**
 * @stable [29.02.2020]
 * @param {IFormWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectForm = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.form; };
/**
 * @stable [27.03.2020]
 * @param {IListWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectList = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.list; };
/**
 * @stable [09.04.2020]
 * @param {IFilterWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.filter;
};
/**
 * @stable [26.03.2020]
 * @param {ITypeWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectType = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.type; };
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectToken = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.token;
};
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectChanges = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.changes;
};
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.entity;
};
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.data;
};
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectActiveValue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.activeValue;
};
/**
 * @stable [30.03.2020]
 * @param {IPayloadWrapper<TPayload>} wrapper
 * @returns {TPayload}
 */
exports.selectPayload = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.payload;
};
/**
 * @stable [30.03.2020]
 * @param {IEffectsAction} action
 * @returns {TPayload}
 */
exports.selectDataPayloadFromAction = function (action) {
    return exports.selectPayload(exports.selectData(action));
};
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
exports.selectValid = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.valid;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectValidFromAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : exports.selectValid(wrapper.data);
};
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffects = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.preventEffects;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectPreventEffectsFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.coalesce(exports.selectPreventEffects(wrapper.data), exports.selectPreventEffects(wrapper.initialData));
};
/**
 *
 * @param {IPreviousActionWrapperEntity} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.previousAction;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
exports.selectPreviousActionFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.coalesce(exports.selectPreviousAction(wrapper.data), exports.selectPreviousAction(wrapper.initialData));
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
exports.selectPreviousActionTypeFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectPreviousActionFromAction(action), function (previousAction) { return exports.selectType(previousAction); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {ISelectedWrapper<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
exports.selectSelected = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.selected;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
exports.selectSelectedEntityFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectData(action), function (data) { return exports.selectSelected(data); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
exports.selectSelectedEntityIdFromAction = function (action) {
    return cond_1.ifNotNilThanValue(exports.selectSelectedEntityFromAction(action), function (entity) { return exports.selectEntityId(entity); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [30.03.2020]
 * @param {IUserWrapper<TUser>} wrapper
 * @returns {TUser}
 */
exports.selectUser = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.user;
};
/**
 * @stable [30.03.2020]
 * @param {IStackWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
exports.selectStack = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.stack;
};
/**
 * @stable [30.03.2020]
 * @param {ITransportWrapper<TTransport>} wrapper
 * @returns {TTransport}
 */
exports.selectTransport = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.transport;
};
/**
 * @stable [30.03.2020]
 * @param {IDictionariesWrapper<TDictionaries>} wrapper
 * @returns {TDictionaries}
 */
exports.selectDictionaries = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.dictionaries;
};
/**
 * @stable [30.03.2020]
 * @param {ISectionNameWrapper} wrapper
 * @returns {string}
 */
exports.selectSectionName = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.sectionName;
};
/**
 * @stable [30.03.2020]
 * @param {IListWrapperEntity<TEntity extends IEntity>} listWrapperEntity
 * @returns {TEntity}
 */
exports.selectListSelectedEntity = function (listWrapperEntity) {
    return cond_1.ifNotNilThanValue(exports.selectList(listWrapperEntity), function (list) { return exports.selectSelected(list); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [04.04.2020]
 * @param {IDirectionsWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectDirections = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.directions;
};
/**
 * @stable [04.04.2020]
 * @param {IGenericListEntity} entity
 * @returns {ISortDirectionsEntity}
 */
exports.selectListEntityDirections = function (entity) {
    return exports.selectDirections(entity);
};
/**
 * @stable [09.04.2020]
 * @param {IListWrapperEntity} listWrapperEntity
 * @returns {TData}
 */
exports.selectListWrapperRawDataEntity = function (listWrapperEntity) {
    return exports.selectRawData(exports.selectList(listWrapperEntity));
};
/**
 * @stable [09.04.2020]
 * @param {IFormEditableEntity<TEntity>} entity
 * @returns {TEntity}
 */
exports.selectFormEditableEntityChanges = function (entity) {
    return exports.selectChanges(exports.selectForm(entity));
};
/**
 * @stable [09.04.2020]
 * @param {IGenericEditableEntity} editableEntity
 * @returns {ToolbarToolsEnum[]}
 */
exports.selectEditableEntityToolbarToolsActiveFilter = function (editableEntity) {
    return cond_1.ifNotEmptyThanValue(exports.selectChanges(editableEntity), function () { return [definition_1.ToolbarToolsEnum.FILTER]; }, []);
};
//# sourceMappingURL=select.js.map